# xpdAcq
[![Build Status](https://travis-ci.org/xpdAcq/xpdAcq.svg?branch=master)](https://travis-ci.org/xpdAcq/xpdAcq)
[![codecov](https://codecov.io/gh/xpdAcq/xpdAcq/branch/master/graph/badge.svg)](https://codecov.io/gh/xpdAcq/xpdAcq)
[![Code Health](https://landscape.io/github/xpdAcq/xpdAcq/master/landscape.svg?style=flat)](https://landscape.io/github/xpdAcq/xpdAcq/master)
[![Anaconda-Server Badge](https://anaconda.org/nsls2forge/xpdacq/badges/version.svg)](https://anaconda.org/nsls2forge/xpdacq)

Acquisition packages for XPD-28 beamline at BNL
